@@ -1,5 +1,5 @@
 
-# $Id: pqfunctions.R 409 2014-12-01 15:58:09Z thothorn $
+# $Id: pqfunctions.R 481 2021-08-23 15:09:18Z thothorn $
 
 pqglht <- function(object) 
 {
@@ -114,9 +114,9 @@ global <- function(type = c("Chisq", "F"))
         m <- coef(object, rhs = TRUE)
         covm <- vcov(object)
 
-        tmp <- betahat - m
+        tmp <- matrix(betahat - m, ncol = 1L)
         MP <- MPinv(covm)
-        SSH <- t(tmp) %*% MP$MPinv %*% tmp
+        SSH <- crossprod(tmp, MP$MPinv %*% tmp)
 
         q <- MP$rank
         if (type == "F") {
